package backend

import (
	"context"
	"kpt-pasture/model"
	"net/http"

	pasturePb "gitee.com/xuyiping_admin/go_proto/proto/go/backend/cow"
	"gitee.com/xuyiping_admin/pkg/xerr"
)

func (s *StoreEntry) IndicatorsComparison(ctx context.Context, req *pasturePb.IndicatorsComparisonRequest) (*model.IndicatorsComparisonResponse, error) {
	userModel, err := s.GetUserModel(ctx)
	if err != nil {
		return nil, xerr.WithStack(err)
	}

	indicatorsDataList := make([]*model.IndicatorsData, 0)
	pref := s.DB.Model(new(model.IndicatorsData)).
		Where("pasture_id = ?", userModel.AppPasture.Id).
		Where("date IN (?)", req.DateList)
	if req.CategoryKind > 0 {
		pref.Where("category_type = ?", req.CategoryKind)
	}

	if len(req.KindList) > 0 {
		pref.Where("kind IN (?)", req.KindList)
	}

	if err = pref.Order("date,kind").Find(&indicatorsDataList).Error; err != nil {
		return nil, xerr.WithStack(err)
	}

	indicatorsDetails := make(map[string]*model.IndicatorsDetails)
	indicatorsDetailsList, err := s.FindIndicatorsDetailsList(ctx)
	if err != nil {
		return nil, xerr.WithStack(err)
	}
	for _, v := range indicatorsDetailsList {
		indicatorsDetails[v.Kind] = v
	}

	return &model.IndicatorsComparisonResponse{
		Code: http.StatusOK,
		Msg:  "ok",
		Data: model.IndicatorsDataSlice(indicatorsDataList).ToPB(indicatorsDetails),
	}, nil
}
